( cd opt/kde/share/doc/HTML/ja/kdesu ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kdesu ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf fdl-license )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf qpl-license.html )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf x11-license.html )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf 1.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/1.png 1.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf xml.dcl )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf 2.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/2.png 2.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf 3.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/3.png 3.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf 4.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/4.png 4.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf 5.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/5.png 5.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf 6.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/6.png 6.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf 7.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/7.png 7.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf 8.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/8.png 8.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf 9.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/9.png 9.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf headerbg.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf gpl-license.html )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf mainheader.html )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf grad.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/grad.png grad.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf kde-web.css )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf lgpl-license.html )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf doxygen.css )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf web-doctop.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf kde-default.css )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf kmenu.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf footer.html )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/footer.html footer.html )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf kde-common.css )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf doctop1.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf doctop2.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf shadow.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf docheadergears.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf fdl-license.html )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf doctop1a.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf 10.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/10.png 10.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf doctop1b.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf lgpl-license )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf mainfooter.html )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf bottom1.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf bottom2.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf header.html )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/header.html header.html )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf gpl-license )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf kde-localised.css.template )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf bsd-license.html )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf web-docbottom.png )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd opt/kde/share/doc/HTML/ja/common ; rm -rf artistic-license.html )
( cd opt/kde/share/doc/HTML/ja/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd opt/kde/share/doc/HTML/ja/kcontrol/smb ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/spellchecking ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/bell ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/arts ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/keys ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/powerctrl ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/cookies ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/filetypes ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/desktop ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/email ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/fonts ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/icons ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/khtml ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/mouse ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/proxy ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/passwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/ebrowsing ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/colors ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/crypto ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/netpref ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmlaunch ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmcss ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/laptop ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmnotify ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmsmserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/screensaver ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/windowmanagement ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kwindecoration ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmkonsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/useragent ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/keyboard ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmtaskbar ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kthememgr ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kspell ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/blockdevices ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/samba ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/ja/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/ja/common common )
